;/******************************/;
;/* Example For : JRHC08JL3 V1 */;
;/* Controller  : 68HC908JL3   */;
;/* Assembler   : C32D4CL.EXE  */;
;/* Demo For Output Port Test  */;
;/******************************/;
;
;/*************************/;
;/* Register HC08 Equates */;
;/*************************/;
;
PORTA       EQU     $0000                   ; Port-A Data Register
PORTB       EQU     $0001                   ; Port-B Data Register
PORTD       EQU     $0003                   ; Port-D Data Regsiter
DDRA        EQU     $0004                   ; Port-A Direction Register
DDRB        EQU     $0005                   ; Port-B Direction Register
DDRD        EQU     $0007                   ; Port-D Direction Register
PDCR        EQU     $000A                   ; Port-D Control Register
PTAPUE      EQU     $000D                   ; Port-A Pull-Up Enable
KBSCR       EQU     $001A                   ; Keyboard Status Control
KBIER       EQU     $001B                   ; Keyboard Interrupt Enable
INTSCR      EQU     $001D                   ; IRQ Status Control
CONFIG2     EQU     $001E                   ; Config Register2
CONFIG1     EQU     $001F                   ; Config Register1
TSC         EQU     $0020                   ; TIM Status & Control
TCNTH       EQU     $0021                   ; TIM Counter High
TCNTL       EQU     $0022                   ; TIM Counter Low
TMODH       EQU     $0023                   ; TIM Counter Modulo High
TMODL       EQU     $0024                   ; TIM Counter Modulo Low
TSC0        EQU     $0025                   ; TIM CH0 Status & Control
TCH0H       EQU     $0026                   ; TIM CH0 High
TCH0L       EQU     $0027                   ; TIM CH0 Low
TSC1        EQU     $0028                   ; TIM CH1 Status & Control
TCH1H       EQU     $0029                   ; TIM CH1 High
TCH1L       EQU     $002A                   ; TIM CH1 Low
ADSCR       EQU     $003C                   ; ADC Status & Control
ADR         EQU     $003D                   ; ADC Data Read
ADICLK      EQU     $003E                   ; ADC Input Clock
BSR         EQU     $FE00                   ; Break Status Register
RSR         EQU     $FE01                   ; Reset Status Register
BFCR        EQU     $FE03                   ; Break Flag Control
INT1        EQU     $FE04                   ; Interrupt Status1
INT2        EQU     $FE05                   ; Interrupt Status2
INT3        EQU     $FE06                   ; Interrupt Status3
FLCR        EQU     $FE08                   ; Flash Control Register
FLBPR       EQU     $FE09                   ; Flash Block Protect
BRKH        EQU     $FE0C                   ; Break Address High
BRKL        EQU     $FE0D                   ; Break Address Low
BRKSCR      EQU     $FE0E                   ; Break Status & Control
COPCTL      EQU     $FFFF                   ; Reset COP
;/* End Equate I/O Register of HC08 */;

            ORG     $80
DLY_BUFF    DFS     1                       ; Deley Buffer

            ;/****************************/;
            ;/* 68HC908JL3 Port I/O Test */;
            ;/****************************/;
            ;
            CPU     "68HC08.TBL"            ; 68HC908JL3 Table
            HOF     "MOT8"                  ; S19 Hex Format
            ORG     $EC00                   ; Start Main (68HC908JL3)
            ;
RESET:      BSET    0,CONFIG1               ; Disable COP Watch-Dog
            LDA     #$FF                    ; Port Direction = Output
            STA     DDRA
            STA     DDRB
            STA     DDRD
            ;
            LDA     #00000000B              ; Data to movlight
            SEC                             ; Set Carry Flag
LOOP:       STA     PORTA                   ; Display Port-A
            STA     PORTB                   ; Display Port-B
            STA     PORTD                   ; Display Port-D
            ;
            MOV     #250,DLY_BUFF           ; Delay 250mS
            JSR     DLY_MSEC
            MOV     #250,DLY_BUFF           ; Delay 250mS
            JSR     DLY_MSEC
            ;
            ROLA                            ; CY <- [ACC] <- CY
            JMP     LOOP

;/*******************/;
;/* Delay Time 1 mS */;
;/* CPU Bus = 8 MHz */;
;/* 1Cycle = 1/8MHz */;
;/* 1mS = 8000Cycle */;
;/* Input :DLY_BUFF */;
;/*******************/;
;
DLY_MSEC:   PSHH                            ; Save Register (2 Cycle)
            PSHX                            ; 2 Cycle
            PSHA                            ; 2 Cycle
            TPA                             ; CCR -> A (1 Cycle)
            PSHA                            ; 2 Cycle
            LDA     DLY_BUFF                ; 3 Cycle (Get Delay)
            ;
DLY_MS0:    LDHX    #886                    ; 3 Cycle
DLY_MS1:    NOP                             ; 1 Cycle
            AIX     #-1                     ; H:X - 1 (2 Cycle)
            CPHX    #0                      ; 3 Cycle
            BNE     DLY_MS1                 ; 3 Cycle ( 9 x 886 = 8000 Cycle)
            DBNZA   DLY_MS0                 ; 3 Cycle
            ;
            PULA                            ; 2 Cycle
            TAP                             ; A -> CCR (2 Cycle)
            PULA                            ; 2 Cycle
            PULX                            ; 2 Cycle
            PULH                            ; 2 Cycle
            RTS                             ; 4 Cycle

            ;/***************/;
            ;/* User Vector */;
            ;/***************/;
            ;
            ORG     $FFF6                   ; Security Code
            DFB     "JRHC08V1"
            ORG     $FFFE                   ; Reset Vector
            DWM     RESET               

            END

